==> moserial-1.0.7.tar.bz2: moserial-1.0.7/src/Main.c <==

#include <src/Main.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <config.h>
#include <stdio.h>
#include "src/MainWindow.h"




enum  {
	MOSERIAL_MAIN_DUMMY_PROPERTY
};
static char* moserial_main_profileFilename = NULL;
static gpointer moserial_main_parent_class = NULL;
static void moserial_main_finalize (GObject* obj);

static const GOptionEntry MOSERIAL_MAIN_options[] = {{"profile", 'p', 0, G_OPTION_ARG_FILENAME, &moserial_main_profileFilename, N_ ("Profile file to load"), "foo.conf"}, {NULL}};


void moserial_main_run (moserialMain* self) {
	GError * inner_error;
	moserialMainWindow* mainWindow;
	GtkBuilder* builder;
	moserialMainWindow* _tmp0;
	g_return_if_fail (self != NULL);
	inner_error = NULL;
	mainWindow = NULL;
	builder = gtk_builder_new ();
	{
		gtk_builder_add_from_file (builder, MOSERIAL_GLADEDIR "/moserial.ui", &inner_error);
		if (inner_error != NULL) {
			goto __catch4_g_error;
			goto __finally4;
		}
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
			GtkMessageDialog* msg;
			msg = g_object_ref_sink ((GtkMessageDialog*) gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL, _ ("Failed to load UI\n%s"), e->message, NULL));
			gtk_dialog_run ((GtkDialog*) msg);
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			(msg == NULL) ? NULL : (msg = (g_object_unref (msg), NULL));
		}
	}
	__finally4:
	if (inner_error != NULL) {
		(mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL));
		(builder == NULL) ? NULL : (builder = (g_object_unref (builder), NULL));
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
		return;
	}
	_tmp0 = NULL;
	mainWindow = (_tmp0 = g_object_ref_sink (moserial_main_window_new (builder, moserial_main_profileFilename)), (mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL)), _tmp0);
	moserial_main_window_showWindow (mainWindow);
	(mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL));
	(builder == NULL) ? NULL : (builder = (g_object_unref (builder), NULL));
}


gint moserial_main_main (char** args, int args_length1) {
	GError * inner_error;
	GOptionContext* context;
	gint _tmp1;
	inner_error = NULL;
	gtk_init (&args_length1, &args);
	context = g_option_context_new (_ ("- moserial serial terminal"));
	g_option_context_add_main_entries (context, MOSERIAL_MAIN_options, NULL);
	g_option_context_add_group (context, gtk_get_option_group (TRUE));
	{
		gboolean _tmp0;
		_tmp0 = g_option_context_parse (context, &args_length1, &args, &inner_error);
		if (inner_error != NULL) {
			if (inner_error->domain == G_OPTION_ERROR) {
				goto __catch5_g_option_error;
			}
			goto __finally5;
		}
		if (!_tmp0) {
			fprintf (stdout, _ ("Run '%s --help' to see a full list of available command line options.\n"), args[0]);
		} else {
			moserialMain* app;
			app = moserial_main_new ();
			moserial_main_run (app);
			gtk_main ();
			(app == NULL) ? NULL : (app = (g_object_unref (app), NULL));
		}
	}
	goto __finally5;
	__catch5_g_option_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
			fprintf (stdout, "%s\n", e->message);
			fprintf (stdout, _ ("Run '%s --help' to see a full list of available command line options.\n"), args[0]);
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
		}
	}
	__finally5:
	if (inner_error != NULL) {
		(context == NULL) ? NULL : (context = (g_option_context_free (context), NULL));
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
		return 0;
	}
	return (_tmp1 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp1);
}


int main (int argc, char ** argv) {
	g_type_init ();
	return moserial_main_main (argv, argc);
}


moserialMain* moserial_main_construct (GType object_type) {
	moserialMain * self;
	self = g_object_newv (object_type, 0, NULL);
	return self;
}


moserialMain* moserial_main_new (void) {
	return moserial_main_construct (MOSERIAL_TYPE_MAIN);
}


static void moserial_main_class_init (moserialMainClass * klass) {
	moserial_main_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = moserial_main_finalize;
}


static void moserial_main_instance_init (moserialMain * self) {
}


static void moserial_main_finalize (GObject* obj) {
	moserialMain * self;
	self = MOSERIAL_MAIN (obj);
	G_OBJECT_CLASS (moserial_main_parent_class)->finalize (obj);
}


GType moserial_main_get_type (void) {
	static GType moserial_main_type_id = 0;
	if (moserial_main_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (moserialMainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) moserial_main_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (moserialMain), 0, (GInstanceInitFunc) moserial_main_instance_init, NULL };
		moserial_main_type_id = g_type_register_static (G_TYPE_OBJECT, "moserialMain", &g_define_type_info, 0);
	}
	return moserial_main_type_id;
}

==> moserial-1.0.8.tar.bz2: moserial-1.0.8/src/Main.c <==

#include <src/Main.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <config.h>
#include <stdio.h>
#include "src/MainWindow.h"




enum  {
	MOSERIAL_MAIN_DUMMY_PROPERTY
};
static char* moserial_main_profileFilename = NULL;
static gpointer moserial_main_parent_class = NULL;
static void moserial_main_finalize (GObject* obj);

static const GOptionEntry MOSERIAL_MAIN_options[] = {{"profile", 'p', 0, G_OPTION_ARG_FILENAME, &moserial_main_profileFilename, N_ ("Profile file to load"), "foo.conf"}, {NULL}};


void moserial_main_run (moserialMain* self) {
	GError * inner_error;
	moserialMainWindow* mainWindow;
	GtkBuilder* builder;
	gboolean _tmp0;
	moserialMainWindow* _tmp3;
	g_return_if_fail (self != NULL);
	inner_error = NULL;
	mainWindow = NULL;
	builder = gtk_builder_new ();
	{
		gtk_builder_add_from_file (builder, MOSERIAL_GLADEDIR "/moserial.ui", &inner_error);
		if (inner_error != NULL) {
			goto __catch4_g_error;
			goto __finally4;
		}
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
			GtkMessageDialog* msg;
			msg = g_object_ref_sink ((GtkMessageDialog*) gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL, _ ("Failed to load UI\n%s"), e->message, NULL));
			gtk_dialog_run ((GtkDialog*) msg);
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
			(msg == NULL) ? NULL : (msg = (g_object_unref (msg), NULL));
		}
	}
	__finally4:
	if (inner_error != NULL) {
		(mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL));
		(builder == NULL) ? NULL : (builder = (g_object_unref (builder), NULL));
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
		return;
	}
	_tmp0 = FALSE;
	if (!(moserial_main_profileFilename == NULL)) {
		_tmp0 = !g_path_is_absolute (moserial_main_profileFilename);
	} else {
		_tmp0 = FALSE;
	}
	if (_tmp0) {
		char* _tmp2;
		char* _tmp1;
		_tmp2 = NULL;
		_tmp1 = NULL;
		moserial_main_profileFilename = (_tmp2 = g_build_filename (_tmp1 = g_get_current_dir (), moserial_main_profileFilename, NULL), moserial_main_profileFilename = (g_free (moserial_main_profileFilename), NULL), _tmp2);
		_tmp1 = (g_free (_tmp1), NULL);
	}
	_tmp3 = NULL;
	mainWindow = (_tmp3 = g_object_ref_sink (moserial_main_window_new (builder, moserial_main_profileFilename)), (mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL)), _tmp3);
	moserial_main_window_showWindow (mainWindow);
	(mainWindow == NULL) ? NULL : (mainWindow = (g_object_unref (mainWindow), NULL));
	(builder == NULL) ? NULL : (builder = (g_object_unref (builder), NULL));
}


gint moserial_main_main (char** args, int args_length1) {
	GError * inner_error;
	GOptionContext* context;
	gint _tmp1;
	inner_error = NULL;
	gtk_init (&args_length1, &args);
	context = g_option_context_new (_ ("- moserial serial terminal"));
	g_option_context_add_main_entries (context, MOSERIAL_MAIN_options, NULL);
	g_option_context_add_group (context, gtk_get_option_group (TRUE));
	{
		gboolean _tmp0;
		_tmp0 = g_option_context_parse (context, &args_length1, &args, &inner_error);
		if (inner_error != NULL) {
			if (inner_error->domain == G_OPTION_ERROR) {
				goto __catch5_g_option_error;
			}
			goto __finally5;
		}
		if (!_tmp0) {
			fprintf (stdout, _ ("Run '%s --help' to see a full list of available command line options.\n"), args[0]);
		} else {
			moserialMain* app;
			app = moserial_main_new ();
			moserial_main_run (app);
			gtk_main ();
			(app == NULL) ? NULL : (app = (g_object_unref (app), NULL));
		}
	}
	goto __finally5;
	__catch5_g_option_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
			fprintf (stdout, "%s\n", e->message);
			fprintf (stdout, _ ("Run '%s --help' to see a full list of available command line options.\n"), args[0]);
			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
		}
	}
	__finally5:
	if (inner_error != NULL) {
		(context == NULL) ? NULL : (context = (g_option_context_free (context), NULL));
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
		return 0;
	}
	return (_tmp1 = 0, (context == NULL) ? NULL : (context = (g_option_context_free (context), NULL)), _tmp1);
}


int main (int argc, char ** argv) {
	g_type_init ();
	return moserial_main_main (argv, argc);
}


moserialMain* moserial_main_construct (GType object_type) {
	moserialMain * self;
	self = g_object_newv (object_type, 0, NULL);
	return self;
}


moserialMain* moserial_main_new (void) {
	return moserial_main_construct (MOSERIAL_TYPE_MAIN);
}


static void moserial_main_class_init (moserialMainClass * klass) {
	moserial_main_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = moserial_main_finalize;
}


static void moserial_main_instance_init (moserialMain * self) {
}


static void moserial_main_finalize (GObject* obj) {
	moserialMain * self;
	self = MOSERIAL_MAIN (obj);
	G_OBJECT_CLASS (moserial_main_parent_class)->finalize (obj);
}


GType moserial_main_get_type (void) {
	static GType moserial_main_type_id = 0;
	if (moserial_main_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (moserialMainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) moserial_main_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (moserialMain), 0, (GInstanceInitFunc) moserial_main_instance_init, NULL };
		moserial_main_type_id = g_type_register_static (G_TYPE_OBJECT, "moserialMain", &g_define_type_info, 0);
	}
	return moserial_main_type_id;
}
